@@ -20,7 +20,7 @@ for repo in _ANDROID_REPO_MANIFESTS.keys():
   _repo_manifests_locks[repo] = Lock()
 
 async def _get_repo_manifest(repo):
-  with (await _repo_manifests_locks[repo]):
+  async with _repo_manifests_locks[repo]:
     if repo in _repo_manifests_cache:
       return _repo_manifests_cache[repo]
 
@@ -45,7 +45,7 @@ async def get_version(name, conf, **kwargs):
       continue
     for archive in pkg.findall('./archives/archive'):
       host_os = archive.find('./host-os')
-      if host_os and host_os.text != 'linux':
+      if host_os is not None and host_os.text != 'linux':
         continue
       archive_url = archive.find('./complete/url').text
       # revision
