@@ -1,7 +1,9 @@
 # MIT licensed
 # Copyright (c) 2013-2017 lilydjwg <lilydjwg@gmail.com>, et al.
 
-from . import cmd
+from . import cmd, conf_cacheable_with_name
+
+get_cacheable_conf = conf_cacheable_with_name('debianpkg')
 
 async def get_version(name, conf, **kwargs):
   referree = conf.get('pacman') or name
